fn untouchable_adts(translated: &TranslatedCrate) -> HashSet<TypeDeclId>Expand description
ADTs that have at least one trait clause pointing at a trait with associated types (transitively). We leave these ADTs entirely untouched.
fn untouchable_adts(translated: &TranslatedCrate) -> HashSet<TypeDeclId>ADTs that have at least one trait clause pointing at a trait with associated types (transitively). We leave these ADTs entirely untouched.